# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Dict, List, Mapping, Optional, Tuple, Union
from . import _utilities, _tables

__all__ = ['ProjectIpWhitelist']


class ProjectIpWhitelist(pulumi.CustomResource):
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 aws_security_group: Optional[pulumi.Input[str]] = None,
                 cidr_block: Optional[pulumi.Input[str]] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 ip_address: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        `ProjectIpWhitelist` provides an IP Whitelist entry resource. The whitelist grants access from IPs, CIDRs or AWS Security Groups (if VPC Peering is enabled) to clusters within the Project.

        > **NOTE:** Groups and projects are synonymous terms. You may find `groupId` in the official documentation.

        > **IMPORTANT:**
        When you remove an entry from the whitelist, existing connections from the removed address(es) may remain open for a variable amount of time. How much time passes before Atlas closes the connection depends on several factors, including how the connection was established, the particular behavior of the application or driver using the address, and the connection protocol (e.g., TCP or UDP). This is particularly important to consider when changing an existing IP address or CIDR block as they cannot be updated via the Provider (comments can however), hence a change will force the destruction and recreation of entries.

        ## Example Usage
        ### Using CIDR Block
        ```python
        import pulumi
        import pulumi_mongodbatlas as mongodbatlas

        test = mongodbatlas.ProjectIpWhitelist("test",
            cidr_block="1.2.3.4/32",
            comment="cidr block for tf acc testing",
            project_id="<PROJECT-ID>")
        ```
        ### Using IP Address
        ```python
        import pulumi
        import pulumi_mongodbatlas as mongodbatlas

        test = mongodbatlas.ProjectIpWhitelist("test",
            comment="ip address for tf acc testing",
            ip_address="2.3.4.5",
            project_id="<PROJECT-ID>")
        ```
        ### Using an AWS Security Group
        ```python
        import pulumi
        import pulumi_mongodbatlas as mongodbatlas

        test_network_container = mongodbatlas.NetworkContainer("testNetworkContainer",
            project_id="<PROJECT-ID>",
            atlas_cidr_block="192.168.208.0/21",
            provider_name="AWS",
            region_name="US_EAST_1")
        test_network_peering = mongodbatlas.NetworkPeering("testNetworkPeering",
            project_id="<PROJECT-ID>",
            container_id=test_network_container.container_id,
            accepter_region_name="us-east-1",
            provider_name="AWS",
            route_table_cidr_block="172.31.0.0/16",
            vpc_id="vpc-0d93d6f69f1578bd8",
            aws_account_id="232589400519")
        test_project_ip_whitelist = mongodbatlas.ProjectIpWhitelist("testProjectIpWhitelist",
            project_id="<PROJECT-ID>",
            aws_security_group="sg-0026348ec11780bd1",
            comment="TestAcc for awsSecurityGroup",
            opts=ResourceOptions(depends_on=["mongodbatlas_network_peering.test"]))
        ```

        > **IMPORTANT:** In order to use AWS Security Group(s) VPC Peering must be enabled like above example.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] aws_security_group: ID of the whitelisted AWS security group. Mutually exclusive with `cidr_block` and `ip_address`.
        :param pulumi.Input[str] cidr_block: Whitelist entry in Classless Inter-Domain Routing (CIDR) notation. Mutually exclusive with `aws_security_group` and `ip_address`.
        :param pulumi.Input[str] comment: Comment to add to the whitelist entry.
        :param pulumi.Input[str] ip_address: Whitelisted IP address. Mutually exclusive with `aws_security_group` and `cidr_block`.
        :param pulumi.Input[str] project_id: The ID of the project in which to add the whitelist entry.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['aws_security_group'] = aws_security_group
            __props__['cidr_block'] = cidr_block
            __props__['comment'] = comment
            __props__['ip_address'] = ip_address
            if project_id is None:
                raise TypeError("Missing required property 'project_id'")
            __props__['project_id'] = project_id
        super(ProjectIpWhitelist, __self__).__init__(
            'mongodbatlas:index/projectIpWhitelist:ProjectIpWhitelist',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            aws_security_group: Optional[pulumi.Input[str]] = None,
            cidr_block: Optional[pulumi.Input[str]] = None,
            comment: Optional[pulumi.Input[str]] = None,
            ip_address: Optional[pulumi.Input[str]] = None,
            project_id: Optional[pulumi.Input[str]] = None) -> 'ProjectIpWhitelist':
        """
        Get an existing ProjectIpWhitelist resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] aws_security_group: ID of the whitelisted AWS security group. Mutually exclusive with `cidr_block` and `ip_address`.
        :param pulumi.Input[str] cidr_block: Whitelist entry in Classless Inter-Domain Routing (CIDR) notation. Mutually exclusive with `aws_security_group` and `ip_address`.
        :param pulumi.Input[str] comment: Comment to add to the whitelist entry.
        :param pulumi.Input[str] ip_address: Whitelisted IP address. Mutually exclusive with `aws_security_group` and `cidr_block`.
        :param pulumi.Input[str] project_id: The ID of the project in which to add the whitelist entry.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["aws_security_group"] = aws_security_group
        __props__["cidr_block"] = cidr_block
        __props__["comment"] = comment
        __props__["ip_address"] = ip_address
        __props__["project_id"] = project_id
        return ProjectIpWhitelist(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="awsSecurityGroup")
    def aws_security_group(self) -> pulumi.Output[str]:
        """
        ID of the whitelisted AWS security group. Mutually exclusive with `cidr_block` and `ip_address`.
        """
        return pulumi.get(self, "aws_security_group")

    @property
    @pulumi.getter(name="cidrBlock")
    def cidr_block(self) -> pulumi.Output[str]:
        """
        Whitelist entry in Classless Inter-Domain Routing (CIDR) notation. Mutually exclusive with `aws_security_group` and `ip_address`.
        """
        return pulumi.get(self, "cidr_block")

    @property
    @pulumi.getter
    def comment(self) -> pulumi.Output[str]:
        """
        Comment to add to the whitelist entry.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> pulumi.Output[str]:
        """
        Whitelisted IP address. Mutually exclusive with `aws_security_group` and `cidr_block`.
        """
        return pulumi.get(self, "ip_address")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[str]:
        """
        The ID of the project in which to add the whitelist entry.
        """
        return pulumi.get(self, "project_id")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

